@@ -3,6 +3,7 @@
 #' @description  Function is training h2o deep learning model to match manually classified patterns of the financial
 #' indicator. Main idea is to be able to detect Market Type by solely relying on the current indicator pattern.
 #' This is in the attempt to evaluate current market type and to use proper trading strategy.
+#' Function will always try to gather mode data to update the model.
 #'
 #' Selected Market Periods according to the theory from Van K. Tharp:
 #' 1. Bull normal, BUN
@@ -18,10 +19,14 @@
 #' @author (C) 2020 Vladimir Zhbanko
 #' @backref Market Type research of Van Tharp Institute: <https://www.vantharp.com/>
 #'
-#' @param indicator_dataset   Dataset containing indicator patterns to train the model
-#' @param num_bars            Number of bars used to detect pattern
-#' @param path_model          Path where the models are be stored
-#' @param path_data           Path where the aggregated historical data is stored, if exists in rds format
+#' @param indicator_dataset   Dataframe, Dataset containing indicator patterns to train the model
+#' @param num_bars            Integer, Number of bars used to detect pattern
+#' @param timeframe           Integer, Data timeframe in Minutes.
+#' @param path_model          String, Path where the models are be stored
+#' @param path_data           String, Path where the aggregated historical data is stored, if exists in rds format
+#' @param activate_balance    Boolean, option to choose if to balance market type classes or not, default TRUE
+#' @param num_nn_options      Integer, value from 1 to 20 or more. Used to change number of variants
+#'                            of the random neural network structures
 #'
 #' @return Function is writing file object with the model
 #' @export
@@ -39,19 +44,22 @@
 #' path_model <- normalizePath(tempdir(),winslash = "/")
 #' path_data <- normalizePath(tempdir(),winslash = "/")
 #'
-#' data(macd_ML2)
+#' data(macd_ML60M)
 #'
 #' Sys.sleep(5)
 #'
-#' # start h2o engine (using all CPU's by default)
-#' h2o.init()
+#' # start h2o engine
+#' h2o.init(nthreads = 2)
 #'
 #'
 #' # performing Deep Learning Regression using the custom function
-#' mt_make_model(indicator_dataset = macd_ML2,
+#' mt_make_model(indicator_dataset = macd_ML60M,
 #'               num_bars = 64,
+#'               timeframe = 60,
 #'               path_model = path_model,
-#'               path_data = path_data)
+#'               path_data = path_data,
+#'               activate_balance = TRUE,
+#'               num_nn_options = 2)
 #'
 #' # stop h2o engine
 #' h2o.shutdown(prompt = FALSE)
@@ -65,7 +73,10 @@
 #'
 mt_make_model <- function(indicator_dataset,
                           num_bars,
-                          path_model, path_data){
+                          timeframe = 60,
+                          path_model, path_data,
+                          activate_balance = TRUE,
+                          num_nn_options = 24){
 
   requireNamespace("dplyr", quietly = TRUE)
   requireNamespace("readr", quietly = TRUE)
@@ -75,7 +86,8 @@ mt_make_model <- function(indicator_dataset,
 
   ## check if the latest data is available
   # construct path to the new data
-  path_newdata <- file.path(path_data, "macd_ai_classified.rds")
+  path_file_name <- paste0("macd_ai_classified_", timeframe, "M.rds")
+  path_newdata <- file.path(path_data, path_file_name)
   if(file.exists(path_newdata)){
     # use new data...
     macd_ML2 <- read_rds(path_newdata) %>%
@@ -103,7 +115,7 @@ mt_make_model <- function(indicator_dataset,
 
   # try different models and choose the best one...
   ### random network structure
-  nn_sets <- sample.int(n = 100, 24) %>% matrix(ncol = 3)
+  nn_sets <- sample.int(n = 100, num_nn_options) %>% matrix(ncol = 3)
 
   for (i in 1:dim(nn_sets)[1]) {
 
@@ -111,7 +123,7 @@ mt_make_model <- function(indicator_dataset,
 
 
   ModelC <- h2o.deeplearning(
-    model_id = "DL_Classification",
+    model_id = paste0("DL_Classification", "_", timeframe, "M"),
     x = names(macd_ML[,1:num_bars]),
     y = "M_T",
     training_frame = macd_ML,
@@ -124,7 +136,7 @@ mt_make_model <- function(indicator_dataset,
     l1 = 1e-4,
     distribution = "AUTO",
     stopping_metric = "AUTO",
-    #balance_classes = T,
+    balance_classes = activate_balance,
     epochs = 200)
 
   #ModelC
@@ -150,7 +162,7 @@ mt_make_model <- function(indicator_dataset,
   lowest_RMSE <- df_res %>% dplyr::slice(which.min(RMSE)) %>% select(-RMSE) %>% unlist() %>% unname()
 
   ModelC <- h2o.deeplearning(
-    model_id = "DL_Classification",
+    model_id = paste0("DL_Classification", "_", timeframe, "M"),
     x = names(macd_ML[,1:num_bars]),
     y = "M_T",
     training_frame = macd_ML,
@@ -163,7 +175,7 @@ mt_make_model <- function(indicator_dataset,
     l1 = 1e-4,
     distribution = "AUTO",
     stopping_metric = "AUTO",
-    #balance_classes = T,
+    balance_classes = activate_balance,
     epochs = 200)
 
 h2o.saveModel(ModelC, path = path_model, force = TRUE)
